AppDeviceIntegrity class
Handles the communication with native platform integrity services.
This class is responsible for requesting the integrity token from Google Play Integrity (Android) or DeviceCheck (iOS) to validate that the device is genuine and untampered.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateIntegrityToken(
{String? cloudProjectNumber}) → Future< String?> - Requests a new integrity token from the underlying platform.