GeoEngine class

The main entry point for the GeoEngine SDK.

Use this class to initialize the tracking system and handle location updates securely.

Constructors

GeoEngine({required String apiKey, String? managementUrl, String? ingestUrl, Duration timeout = const Duration(seconds: 10), bool debug = false, String? androidCloudProjectNumber, Client? client})

Properties

androidCloudProjectNumber String?
final
apiKey String
final
debug bool
final
hashCode int
The hash code for this object.
no setterinherited
ingestUrl String
final
managementUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

close() → void
createGeofence({required String name, required List<List<double>> coordinates, required String webhookUrl}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendLocation({required String deviceId, required double latitude, required double longitude, int? timestamp}) Future<void>
Sends a location point to the GeoEngine system.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

debugSimulateAndroid bool?
getter/setter pair

Static Methods

initialize() Future<void>