GeoEngineException class
Custom exception thrown by the GeoEngine SDK when an error occurs.
- Implemented types
Constructors
- GeoEngineException(String message, {int? statusCode})
- Creates a new GeoEngineException.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A descriptive message of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
Optional HTTP status code associated with the error.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited